@@ -8,6 +8,7 @@ import logging
 import sys
 import subprocess
 import multiprocessing
+import time
 
 import pydub
 from pydub.utils import mediainfo
@@ -50,7 +51,7 @@ my_parser.add_argument(
     "--cpus",
     metavar="cpus",
     nargs=1,
-    default=1,
+    default=[1],
     action="store",
     type=int,
     help="the number of processor cores to utilize",
@@ -111,6 +112,14 @@ def spin_up(folder):
     combined.export(f"~{pathlib.Path(mp3s[0]).stem}-full{_FILETYPE}", tags={"test":"TEST"}, bitrate=bit_rate)
     # End of Merge audio files
 
+    count = 0
+    while not Path(f"~{pathlib.Path(mp3s[0]).stem}-full{_FILETYPE}").exists():
+        if count > 6:
+            return
+        count += 1
+        time.sleep(10)
+
+
     # Convert audio files
     command = [
         "ffmpeg",
@@ -147,6 +156,7 @@ def main():
         + ". \nOk?"
     )
 
+
     with multiprocessing.Pool(_CPUS[0]) as pool:
         pool.map_async(spin_up, folders).get()
 
